Type

Type Alias Type 

pub type Type = u32;
Types of logging messages

Three types exist:

  • ERROR for real, hard, unrecoverable errors that will result in the program terminating.
  • WARNING for things that have gone wrong, but are not requiring a termination of the program.
  • DEBUG for debug messages that can be very verbose but may help the developers to fix bugs.